@@ -2,7 +2,7 @@ package Test2::IPC::Driver::Files;
 use strict;
 use warnings;
 
-our $VERSION = '1.302177';
+our $VERSION = '1.302180';
 
 BEGIN { require Test2::IPC::Driver; our @ISA = qw(Test2::IPC::Driver) }
 
@@ -14,7 +14,7 @@ use Storable();
 use File::Spec();
 use POSIX();
 
-use Test2::Util qw/try get_tid pkg_to_file IS_WIN32 ipc_separator do_rename do_unlink try_sig_mask/;
+use Test2::Util qw/try get_tid pkg_to_file IS_WIN32 ipc_separator do_rename do_unlink/;
 use Test2::API qw/test2_ipc_set_pending/;
 
 sub is_viable { 1 }
@@ -149,6 +149,33 @@ sub drop_hub {
     $self->abort_trace("Not all files from hub '$hid' have been collected!\nHere is the leftover data:\n========================\n$data\n===================\n");
 }
 
+sub try_sig_mask {
+    my $self = shift;
+    my ($code) = @_;
+
+    my ($old, $blocked);
+    unless(IS_WIN32) {
+        my $to_block = POSIX::SigSet->new(
+            POSIX::SIGINT(),
+            POSIX::SIGALRM(),
+            POSIX::SIGHUP(),
+            POSIX::SIGTERM(),
+            POSIX::SIGUSR1(),
+            POSIX::SIGUSR2(),
+        );
+        $old = POSIX::SigSet->new;
+        $blocked = POSIX::sigprocmask(POSIX::SIG_BLOCK(), $to_block, $old);
+        # Silently go on if we failed to log signals, not much we can do.
+    }
+
+    my ($ok, $err) = &try($code);
+
+    # If our block was successful we want to restore the old mask.
+    POSIX::sigprocmask(POSIX::SIG_SETMASK(), $old, POSIX::SigSet->new()) if defined $blocked;
+
+    return ($ok, $err);
+}
+
 sub send {
     my $self = shift;
     my ($hid, $e, $global) = @_;
@@ -181,10 +208,10 @@ do so if Test::Builder is loaded for legacy reasons.
 
     # Write and rename the file.
     my ($ren_ok, $ren_err);
-    my ($ok, $err) = try_sig_mask {
+    my ($ok, $err) = $self->try_sig_mask(sub {
         Storable::store($e, $file);
         ($ren_ok, $ren_err) = do_rename("$file", $ready);
-    };
+    });
 
     if ($ok) {
         $self->abort("Could not rename file '$file' -> '$ready': $ren_err") unless $ren_ok;
@@ -466,9 +493,40 @@ follow template specifications from L<File::Temp>.
 
 =back
 
-=head1 SEE ALSO
+=head1 METHODS
 
-See L<Test2::IPC::Driver> for methods.
+See L<Test2::IPC::Driver> for methods that are inherited or overriden. Only
+methods unique to this driver are listed below.
+
+=over 4
+
+=item ($ok, $err) = $inst->try_sig_mask(sub { ... })
+
+Complete an action with several signals masked, they will be unmasked at the
+end allowing any signals that were intercepted to get handled.
+
+This is primarily used when you need to make several actions atomic (against
+some signals anyway).
+
+Signals that are intercepted:
+
+=over 4
+
+=item SIGINT
+
+=item SIGALRM
+
+=item SIGHUP
+
+=item SIGTERM
+
+=item SIGUSR1
+
+=item SIGUSR2
+
+=back
+
+=back
 
 =head1 SOURCE
 
@@ -493,7 +551,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2019 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2020 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
