@@ -1,8 +1,12 @@
 package Test2::Util::Trace;
 require Test2::EventFacet::Trace;
-@ISA = ('Test2::EventFacet::Trace');
 
-our $VERSION = '1.302174';
+use warnings;
+use strict;
+
+our @ISA = ('Test2::EventFacet::Trace');
+
+our $VERSION = '1.302180';
 
 1;
 
@@ -44,7 +48,7 @@ F<http://github.com/Test-More/test-more/>.
 
 =head1 COPYRIGHT
 
-Copyright 2019 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2020 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
